package jp.co.powerbeans.vbscore.model;

import jp.co.powerbeans.powerql.POQLInitBean;



/**
 * アクション結果の種類マスタ
 * @author amonden
 *
 */
public class ActionResultDef implements POQLInitBean {

	/**
	 * 
	 */
	private static final long serialVersionUID = 7271884733757307217L;

	/**
	 * サービスアクションのアクションタイプ=サービスエース
	 */
	public static final int SERVICE_ACE = 3;

	/**
	 * サービスアクションのアクションタイプ=サービスミス
	 */
	public static final int SERVICE_MISS = 4;

	/**
	 * サーブカットのアクションタイプ=GOOD
	 */
	public static final int SERV_CUT_GOOD = 1;

	/**
	 * スパイクのポイントとなるアクションタイプID
	 */
	public static final int[] SPIKE_POINT = {3,4};

	/**
	 * スパイクの打数となるアクションタイプID
	 */
	public static final int[] SPIKE_NUM = {1,2,3,4,5,6,7};

	/**
	 * アクション結果種類ID
	 */
	private int actionResultDefId;
	
	/**
	 * アクション種類ID
	 */
	private int actionDefId;
	
	/**
	 * アクションタイプID
	 */
	private int type;

	/**
	 * アクションポイント
	 */
	private int point;
	
	/**
	 * アクション結果名
	 */
	private String actionResultName;

	/* (非 Javadoc)
	 * @see jp.co.powerbeans.powerql.POQLInitBean#initialTruncate()
	 */
	public boolean initialTruncate() {
		return true;
	}

	/* (非 Javadoc)
	 * @see jp.co.powerbeans.powerql.POQLInitBean#initialData()
	 */
	public Object[] initialData() {
		ActionResultDef[] defs = {
			//  actionResultDefId, actionDefId, type, point, actionResultName
		    // 1 その他
			 new ActionResultDef(1, 1, 1, 1, "得点")
			,new ActionResultDef(2, 1, 2, -1, "失点")
		    // 2 サーブ
			,new ActionResultDef(3, 2, 1, 0, "続行(効果無)")
			,new ActionResultDef(4, 2, 2, 0, "続行(効果有)")
			,new ActionResultDef(5, 2, 3, 1, "得点(Ace)")
			,new ActionResultDef(6, 2, 4,-1, "失点(Miss)")
		    // 3 サーブカット
			,new ActionResultDef(3, 3, 1, 0, "続行(Good)")
			,new ActionResultDef(4, 3, 2, 0, "続行(Miss)")
			,new ActionResultDef(5, 3, 3, 1, "得点")
			,new ActionResultDef(5, 3, 4,-1, "失点")
		    // 4 スパイク
			,new ActionResultDef(3, 4, 1, 0, "続行(強打)")
			,new ActionResultDef(4, 4, 2, 0, "続行(フェイント)")
			,new ActionResultDef(5, 4, 3, 1, "得点(強打)")
			,new ActionResultDef(5, 4, 4, 1, "得点(フェイント)")
			,new ActionResultDef(6, 4, 5,-1, "失点(強打)")
			,new ActionResultDef(6, 4, 6,-1, "失点(フェイント)")
			,new ActionResultDef(6, 4, 7,-1, "失点(Miss)")
		    // 5 ブロック
			,new ActionResultDef(3, 5, 1, 0, "続行")
			,new ActionResultDef(5, 5, 2, 1, "得点")
			,new ActionResultDef(6, 5, 3,-1, "失点(ワンチ)")
			,new ActionResultDef(6, 5, 4,-1, "失点(Miss)")
		    // 6 トス
			,new ActionResultDef(3, 6, 1, 0, "続行(Good)")
			,new ActionResultDef(4, 6, 2, 0, "続行(Miss)")
			,new ActionResultDef(6, 6, 3,-1, "失点")
		    // 7 レシーブ
			,new ActionResultDef(3, 7, 1, 0, "続行(Good)")
			,new ActionResultDef(4, 7, 2, 0, "続行(Miss)")
			,new ActionResultDef(5, 7, 3, 1, "得点")
			,new ActionResultDef(6, 7, 4,-1, "失点")
		};
		
		return defs;
	}
	
	/**
	 * コンストラクタ
	 */
	public ActionResultDef() {
		super();
	}

	/**
	 * コンストラクタ.
	 * @param id アクション結果種類ID
	 * @param actiondefid アクション種類ID
	 * @param type アクションタイプID
	 * @param point 加算ポイント(1 or 0)
	 * @param name アクション名
	 */
	public ActionResultDef(int id, int actiondefid, int type, int point, String name) {
		super();
		this.actionResultDefId = id;
		this.actionDefId = actiondefid;
		this.type = type;
		this.point = point;
		this.actionResultName = name;
	}

	/**
	 * @return actionDefId を戻します。
	 */
	public int getActionDefId() {
		return actionDefId;
	}

	/**
	 * @param actionDefId 設定する actionDefId。
	 */
	public void setActionDefId(int actionDefId) {
		this.actionDefId = actionDefId;
	}

	/**
	 * @return actionResultDefId を戻します。
	 */
	public int getActionResultDefId() {
		return actionResultDefId;
	}

	/**
	 * @param actionResultDefId 設定する actionResultDefId。
	 */
	public void setActionResultDefId(int actionResultDefId) {
		this.actionResultDefId = actionResultDefId;
	}

	/**
	 * @return actionResultName を戻します。
	 */
	public String getActionResultName() {
		return actionResultName;
	}

	/**
	 * @param actionResultName 設定する actionResultName。
	 */
	public void setActionResultName(String actionResultName) {
		this.actionResultName = actionResultName;
	}

	/**
	 * @return point を戻します。
	 */
	public int getPoint() {
		return point;
	}

	/**
	 * @param point 設定する point。
	 */
	public void setPoint(int point) {
		this.point = point;
	}

	/**
	 * @return type を戻します。
	 */
	public int getType() {
		return type;
	}

	/**
	 * @param type 設定する type。
	 */
	public void setType(int type) {
		this.type = type;
	}


}
