package jp.co.powerbeans.vbscore.swt;

import java.util.Date;

import jp.co.powerbeans.common.swt.ChkConvSwt;
import jp.co.powerbeans.vbscore.CMD;
import jp.co.powerbeans.vbscore.Msg;
import jp.co.powerbeans.vbscore.db.DBUtil;
import jp.co.powerbeans.vbscore.logic.DocumentMgr;
import jp.co.powerbeans.vbscore.logic.ScoreMgr;
import jp.co.powerbeans.vbscore.model.Team;
import jp.co.powerbeans.vbscore.model.TeamAnalyze;
import jp.co.powerbeans.vbscore.swt.parts.GameMiniTableComposit;

import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Table;
import org.eclipse.swt.widgets.Text;

/**
 * プレイヤー分析画面
 * @author amonden
 *
 */
public class AnalayzePlayerSwt extends PBSwt {

	/**
	 * 結果表示テーブル
	 */
	private Table table;
	/**
	 * チーム選択コンボ
	 */
	private Combo teamCombo;
	/**
	 * 検索条件 開始日
	 */
	private Text fromDate;
	/**
	 * 検索条件 終了日
	 */
	private Text toDate;
	/**
	 * 対象試合表示ミニテーブル
	 */
	private GameMiniTableComposit gameTable;

	/**
	 * table の列数
	 */
	static final int COLS = 8;
	/**
	 * table 列幅(default)
	 */
	static final int COLS_WIDTH = 80;
	/**
	 * ウィンドウ幅
	 */
	static final int WINDOW_WIDTH = COLS * COLS_WIDTH;
	/**
	 * ウィンドウ高さ
	 */
	static final int WINDOW_HEIGTH = 700;

	/**
	 * タイトル
	 */
	private static final String TITLE = Msg.getAnalyzePlayPerPlayer();
	/**
	 * メニューラベル1(出力)
	 */
	private static final String[] MENU_LABELS1 = {Msg.getMenuOutput()};
	/**
	 * メニューラベル2(HTML)
	 */
	private static final String[][] MENU_LABELS2 = {
		{Msg.getMenuHtml()
			}
	};
	/**
	 * メニューラベル2のコマンド
	 */
	private static final String[][] MENU_CMDS = {
		{CMD.OUTPUT_HTML 
			}
	};
	/**
	 * table列名
	 */
	private static final String[] TABLE_COLS = {
		Msg.getFullname(), Msg.getPlay(), Msg.getResult(), Msg.getTimes(), Msg.getPercent()};
	/**
	 * table対応プロパティ名
	 */
	private static final String[] TABLE_MODEL_COLS = new String[]{"name", "actionName", "actionResultName", "times", "per"};
	
	/**
	 * テーブル列幅
	 */
	private static final int[] TABLE_COL_WIDTHS = {80,80,100,60,30};

	/**
	 * コンストラクタ
	 */
	public AnalayzePlayerSwt() {
		super();
		initialize();
	}	
	
	/**
	 * 初期化
	 */
	private void initialize() {
		createSShell(TITLE, WINDOW_WIDTH, WINDOW_HEIGTH, true);
		setGridLayout(8);
		createItems();
		createMenu();
	}

	/**
	 * Item生成
	 */
	private void createItems() {
		addLabels(COLS);
		
		// チーム選択コンボ
		setHorizontalSpan(addLabel_right(Msg.getTargetTeam()), 2);
		this.teamCombo = addComboBoxByModel(Team.class, "teamName", CMD.SEL_CHANGE);
		setHorizontalSpan(this.teamCombo, 4);
		selectTop(this.teamCombo);
		addLabels(2);
		
		// 対象期間
		setHorizontalSpan(addLabel_right(Msg.getTargetGameDateSpan()), 2);
		this.fromDate = addTextBox("fromDate");
		addLabel_hvcenter(Msg.getChilda());
		this.toDate = addTextBox("toDate");
		
		addLabels(1);
		addSimpleButton(Msg.getSearchW(), CMD.SEARCH);
		addLabels(2);

		// 対象試合テーブル作成
		createGameTable();
		
		// 詳細テーブル作成
		createTable();
	}

	/**
	 * gameTable生成
	 */
	private void createGameTable() {
		if (gameTable == null) {
			this.gameTable = new GameMiniTableComposit(this.sShell, COLS, false);
//			setHorizontalSpan(this.gameTable, COLS);
		}
	
	}
	
	/**
	 * table生成
	 */
	private void createTable() {
		if (table == null) {
			table = addSimpleTable(TABLE_COLS, TABLE_COL_WIDTHS, 200);
			setHeight(table, 300);
			setHorizontalSpan(table, COLS);
		}
	}

	/**
	 * tableをtaで再描画
	 * @param ta 分析データ
	 */
	private void updateTable(TeamAnalyze[] ta) {
		this.table.removeAll();
		addTable(ta);
	}

	/**
	 * tableにtaを追加
	 * @param ta 分析データ
	 */
	private void addTable(TeamAnalyze[] ta) {
		DBUtil.modelsToSwtTable(table, DBUtil.modelsToStrings(ta, TABLE_MODEL_COLS));
	}

	/**
	 * メニュー作成
	 */
	private void createMenu() {
		create2LayerMenu(MENU_LABELS1, MENU_LABELS2, MENU_CMDS);
	}
	
	/**
	 * HTML出力メニュー選択時
	 */
	public void cmdOutput_html() {
		int team_id = Integer.parseInt(ChkConvSwt.getSelectObjectPK(this.teamCombo));
		DocumentMgr.outputAnalyzePlayer(this.sShell, team_id, this.table, this.gameTable.getTable());
	}
	
	/**
	 * 検索実行時
	 */
	public void cmdSearch() {
		// 検索条件取得
		int team_id = Integer.parseInt(ChkConvSwt.getSelectObjectPK(this.teamCombo));
		Date from_dt = ChkConvSwt.getDate(this.fromDate.getText());
		Date to_dt = ChkConvSwt.getDate(this.toDate.getText());

		// 検索開始
		// 1. チーム
		TeamAnalyze[] ta = ScoreMgr.analayzeSearchPlayers(team_id, from_dt, to_dt);
		
		// 2. 対象試合更新
		this.gameTable.updateByDate(team_id, from_dt, to_dt);
		
		// 更新
		updateTable(ta);
	}
	
	/**
	 * チームコンボ変更時
	 */
	public void cmdSel_change() {
		// 特に処理なし
	}
}
