package jp.co.powerbeans.vbscore.swt;

import java.util.Date;

import jp.co.powerbeans.common.swt.ChkConvSwt;
import jp.co.powerbeans.vbscore.CMD;
import jp.co.powerbeans.vbscore.Msg;
import jp.co.powerbeans.vbscore.MsgSwt;
import jp.co.powerbeans.vbscore.chart.VBChartUtil;
import jp.co.powerbeans.vbscore.logic.ranking.RankingAnalyzer;
import jp.co.powerbeans.vbscore.logic.ranking.RankingAnalyzerFactory;
import jp.co.powerbeans.vbscore.model.GameTeams;
import jp.co.powerbeans.vbscore.model.PlayerRanking;
import jp.co.powerbeans.vbscore.model.RankingDef;
import jp.co.powerbeans.vbscore.model.Team;
import jp.co.powerbeans.vbscore.swt.chart.MiniBarChartSwt;
import jp.co.powerbeans.vbscore.swt.chart.MiniPieChartSwt;
import jp.co.powerbeans.vbscore.swt.chart.NormalBarChartSwt;
import jp.co.powerbeans.vbscore.swt.parts.TeamSearchGroup;

import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Group;

/**
 * チャート付きランキング分析画面(試用提供)
 * @author amonden
 *
 */
public class ChartAnalayzeRankingSwt extends PBSwt {

	/**
	 * table 列数
	 */
	static final int COLS = 1;
	/**
	 * table 各列の列幅
	 */
	static final int COLS_WIDTH = 600;// 120
	/**
	 * ウィンドウ幅
	 */
	static final int WINDOW_WIDTH = COLS * COLS_WIDTH;
	/**
	 * ウィンドウ高さ
	 */
	static final int WINDOW_HEIGTH = 450;

	/**
	 * タイトル
	 */
	private static final String TITLE = Msg.getPlayRankingChart();
	/**
	 * トップレベルメニュー ("出力")
	 */
	private static final String[] MENU_LABELS1 = {Msg.getMenuOutput()};
	/**
	 * サブレベルメニュー("HTML")
	 */
	private static final String[][] MENU_LABELS2 = {
		{Msg.getMenuHtml()
			}
	};
	/**
	 * サブレベルメニューコマンド("HTML")
	 */
	private static final String[][] MENU_CMDS = {
		{CMD.OUTPUT_HTML 
			}
	};
	private Combo rankingDefCombo;
	private TeamSearchGroup teamSearchGroup;
	private Button outputGraphButton;
//	private ChartListGroup chartListGroup;

	/**
	 * コンストラクタ
	 */
	public ChartAnalayzeRankingSwt() {
		super();
		initialize();
	}	
	
	/**
	 * 初期化
	 */
	private void initialize() {
		createSShell(TITLE, WINDOW_WIDTH, WINDOW_HEIGTH, true);
		setGridLayout(COLS);
		createItems();
		createMenu();
	}

	/**
	 * Item作成
	 */
	private void createItems() {
		
		addLabels(COLS, COLS_WIDTH);

		// チーム検索Group作成
		this.teamSearchGroup = new TeamSearchGroup(this.sShell);

		// 分析対象（ランキング）コンボ
		Group rankGroup = createGroupShadowEtchedOut_BEGIN(Msg.getAnalyzeContents(), 2, false);
		this.rankingDefCombo = addComboBoxByModel(rankGroup, RankingDef.class, "rankingName", CMD.SEL_CHANGE_RANKING_TYPE);
		selectTop(this.rankingDefCombo);
		this.outputGraphButton = addSimpleButton(rankGroup, Msg.getOutputGraph(), CMD.OUTPUT_BARGRAPH);
		
//		// 結果チャートリスト表示ビュー > 別ウィンドウで表示する
//		this.chartListGroup = new ChartListGroup(this.sShell);
	}

	/**
	 * メニュー作成
	 */
	private void createMenu() {
//	FIXME	create2LayerMenu(MENU_LABELS1, MENU_LABELS2, MENU_CMDS);
	}

	/**
	 * 円グラフ出力
   * TODO 円グラフでは表現が微妙なので利用しない
	 */
	public void cmdOutput_piegraph() {
		// 検索条件取得
    Team team = this.teamSearchGroup.getSelectTeam();
    RankingDef ranking_def = (RankingDef) ChkConvSwt.getSelectObject(this.rankingDefCombo);
    
    PlayerRanking[] player_ranking = getPlayerRanking(team, ranking_def);
    
		// 結果をテーブル、グラフ表示
		new MiniPieChartSwt(VBChartUtil.createPlayerRankingPieChart(team, player_ranking, ranking_def)).show(); 
	}
	

  /**
   * 棒グラフ出力
   */
  public void cmdOutput_bargraph() {
    // 検索条件取得
    Team team = this.teamSearchGroup.getSelectTeam();
    RankingDef ranking_def = (RankingDef) ChkConvSwt.getSelectObject(this.rankingDefCombo);
    
    PlayerRanking[] player_ranking = getPlayerRanking(team, ranking_def);
    
    // 結果をテーブル、グラフ表示
//    new MiniPieChartSwt(VBChartUtil.createPlayerRankingBarChart(team, player_ranking, ranking_def)).show(); 
    new NormalBarChartSwt(VBChartUtil.createPlayerRankingBarChart(team, player_ranking, ranking_def)).show(); 
  }
	// FIXME HTML出力

  /**
   * 画面の選択値からプレイヤーランキングを表示
   * @param team
   * @param ranking_def
   * @return
   */
  private PlayerRanking[] getPlayerRanking(Team team, RankingDef ranking_def) {
    int team_id = team.getTeamId();
        
    Date from_dt = ChkConvSwt.getDate(this.teamSearchGroup.getFromDate());
    Date to_dt = ChkConvSwt.getDate(this.teamSearchGroup.getToDate());
    
    // 対象試合取得
    if (!this.teamSearchGroup.isSelectGame()) {
      MsgSwt.warn(Msg.getSelectAnalyzeTargetTeam());
      throw new RuntimeException("not select item.");
//      return new PlayerRanking[]{};
    }
    GameTeams[] gteams = this.teamSearchGroup.getSelectGames();
    
    // 対象ランキング取得
    RankingAnalyzer ra = RankingAnalyzerFactory.createInstance(ranking_def);
    PlayerRanking[] player_ranking = ra.analyze(team_id, gteams, from_dt, to_dt);
    return player_ranking;
  }
}
