package jp.co.powerbeans.vbscore.swt;

import jp.co.powerbeans.common.swt.ChkConvSwt;
import jp.co.powerbeans.vbscore.CMD;
import jp.co.powerbeans.vbscore.Msg;
import jp.co.powerbeans.vbscore.MsgSwt;
import jp.co.powerbeans.vbscore.db.DBManager;
import jp.co.powerbeans.vbscore.model.Team;

import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Table;

/**
 * チーム一覧Swt画面
 * @author amonden
 *
 */
public class TeamListSwt extends PBSwt {

	/**
	 * コンポジット
	 */
	private Composite comp;
	/**
	 * テーブル
	 */
	private Table table;

//	int BUTTON_WIDTH = 400;
//	int BUTTON_HEIGTH = 40;
	/**
	 * ウィンドウ幅
	 */
	static final int WINDOW_WIDTH = 420;
	/**
	 * ウィンドウ高さ
	 */
	static final int WINDOW_HEIGTH = 300;

	/**
	 * タイトル
	 */
	private static final String TITLE = Msg.getTeamList();
	/**
	 * トップレベルメニューラベル
	 */
	private static final String[] MENU_LABELS = {Msg.getMenuEdit(), Msg.getMenuAdd(), Msg.getMenuDel()};
	/**
	 * トップレベルメニューコマンド
	 */
	private static final String[] MENU_CMDS = {CMD.EDIT, CMD.ADD, CMD.DEL};
	/**
	 * テーブル列名
	 */
	private static final String[] TABLE_COLS = {Msg.getId(), Msg.getTeamName()};
	/**
	 * テーブル表示プロパティ名
	 */
	private static final String[] TABLE_MODEL_COLS = new String[]{"teamId", "teamName"};
	/**
	 * テーブル列幅
	 */
	private static final int[] TABLE_COL_WIDTHS = {50,150};

	/**
	 * コンストラクタ
	 */
	public TeamListSwt() {
		super();
		initialize();
	}	
	
	/**
	 * 初期化
	 */
	private void initialize() {
		createSShell(TITLE, WINDOW_WIDTH, WINDOW_HEIGTH, true);
		setGridLayout(1);
		createComposit();
		createTable(this.comp);
		createMenu();
	}

	/**
	 * テーブル生成
	 * @param composite コンポジット
	 */
	private void createTable(Composite composite) {
		if (table == null) {
			table = addSimpleTable(TABLE_COLS, TABLE_COL_WIDTHS, 200);
		    setCmdToTableOnDoubleClick(this.table, CMD.EDIT);
		    updateTable();
		}
	}

	/**
	 * 編集ボタン選択時
	 */
	public void cmdEdit() {
		int id = ChkConvSwt.getSelectId(this.table);
		if (CMD.isOk(new TeamEditSwt(CMD.EDIT, id).show())) {
			updateTable();
		}
	}
	
	/**
	 * 追加ボタン選択時
	 */
	public void cmdAdd() {
		if (CMD.isOk(new TeamEditSwt(CMD.ADD, 0).show())) {
			updateTable();
		}
	}
	
	/**
	 * 削除選択時
	 */
	public void cmdDel() {
		deleteTable();
	}

	/**
	 * テーブルの選択行を削除
	 */
	private void deleteTable() {
		int[] ids = ChkConvSwt.getSelectIds(this.table);
		if (MsgSwt.isDelete()) {
			for (int i = 0; i < ids.length; i++) {
				DBManager.removeByPrimaryKey(Team.class, ids[i]);
			}
			updateTable();
		}
	}

	/**
	 * テーブル更新
	 */
	private void updateTable() {
		this.table.removeAll();
		DBManager.findByAllToSwtTable(this.table, Team.class, TABLE_MODEL_COLS);
	}

	/**
	 * コンポジット生成
	 */
	private void createComposit() {
		if (this.comp == null) {
		    this.comp = createNRow1ColComposit(); 
		}
	}

	/**
	 * メニュー生成
	 */
	private void createMenu() {
        create1LayerMenu(MENU_LABELS, MENU_CMDS);
	}
}
