package jp.co.powerbeans.vbscore.swt.parts;

import java.util.ArrayList;
import java.util.List;

import jp.co.powerbeans.vbscore.model.Player;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.PaintEvent;
import org.eclipse.swt.events.PaintListener;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.GC;
import org.eclipse.swt.graphics.Rectangle;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Canvas;

/**
 * ミニコートキャンバス.
 * 選択プレーヤーの表示などで利用
 * @author amonden
 *
 */
public class CoartCanvas extends Canvas {
	/**
	 * ポジション定義
	 */
	private int posi[][] = {
			{50, 100}, // 1
			{135, 100}, // 2
			{135, 70}, // 3
			{135, 40}, // 4
			{50, 40}, // 5
			{50, 70}, // 6
			{40, 5}, // 7
	};
	
	/**
	 * 親Composit
	 */
	private PlayerListCoartComposit parent;
	/**
	 * 表示するプレーヤーリスト
	 */
	private List<Player> playerList;
	
	/**
	 * コンストラクタ
	 * @param composit
	 */
	public CoartCanvas(PlayerListCoartComposit composit) {
		super(composit, SWT.NO_FOCUS);
		this.parent = composit;
		this.playerList = new ArrayList<Player>();
		
		GridData tableGrid = new GridData();
		tableGrid.horizontalAlignment = GridData.FILL;
		tableGrid.verticalAlignment = GridData.FILL;
		tableGrid.grabExcessHorizontalSpace = true;
		tableGrid.grabExcessVerticalSpace = true;
		tableGrid.minimumHeight = 200;
		
		
		setBackground(new Color(getDisplay(), 255, 255, 235));
//		setBounds(0, 0, 400, 400);
		setLayoutData(tableGrid);
		addPaintListener(new PaintListener() {

			public void paintControl(PaintEvent e) {
				Rectangle rect = getClientArea();
				e.gc.setClipping(0, 0, rect.width, rect.height);
				paint(e.gc);
			}});
		
	}

	/**
	 * 描画
	 * @param gc GC
	 */
	protected void paint(GC gc) {
		GC g = gc;
//		int fontsize = g.getFontMetrics().getHeight();
		
		// ネットを描画
		for(int i = 0; i < 2; i++) {
			int dx = 190 + i * 2;
			g.drawLine(dx, 7, dx, 147);
		}
		
		// ラインを描画
		gc.drawRectangle(40, 27, 150, 100);
		gc.drawRectangle(130, 27, 60, 100);
		gc.drawLine(30, 27, 33, 27);
		gc.drawLine(30, 127, 33, 127);
		gc.setTextAntialias(SWT.ON);
		gc.drawString("リベロ ", 0, 0);
		
		// ポジション毎に番号を描画
		for (int i = 0; i < this.posi.length; i++) {
			g.drawRoundRectangle(this.posi[i][0], this.posi[i][1] - 1, 50, 14, 2, 2);
			if (i < playerList.size()) {
				Player p = (Player) playerList.get(i);
				// TODO 文字列を３文字などで区切る
				g.drawString(p.getStdNumber() + ":" + p.getPlayerName(), this.posi[i][0] + 4,
						this.posi[i][1]);
			}
		}
	}

	/**
	 * 次の入力ポジションにプレイヤーを登録する
	 * @param player
	 */
	public void addPlayer(Player player) {
		if (this.playerList.size() == 7) {
			return;
		}
		this.playerList.add(player);
		this.redraw();
	}

	/**
	 * 最後に入力したポジションをクリアする
	 */
	public void removeLastPlayer() {
		if (this.playerList.size() > 0) {
			this.playerList.remove(this.playerList.size() - 1);
		}
		this.redraw();
	}
	
	/**
	 * プレイヤーの入力が最大か.
	 * リベロは入力しなくても最大とみなす
	 * @return
	 */
	public boolean isMaxPlayer() {
		int size = this.playerList.size();
		return size >= 6 && size <= 7;
	}
	
	/**
	 * 選択プレイヤーリストを返す
	 * @return 
	 */
	public Player[] getPlayerList() {
		return (Player[]) this.playerList.toArray(new Player[]{});
	}
	
}
